@@ -2,9 +2,9 @@ fast.lm = function(data, node, parents, keep.fitted = FALSE) {
 
   y = minimal.data.frame.column(data, node)
 
-  .Call("fast_lm",
+  .Call(call_fast_lm,
         data = data,
-        node = node, 
+        node = node,
         parents = parents,
         keep = keep.fitted)
 
@@ -12,7 +12,7 @@ fast.lm = function(data, node, parents, keep.fitted = FALSE) {
 
 fast.cglm = function(data, node, parents, configs, keep.fitted = FALSE) {
 
-  .Call("fast_cglm",
+  .Call(call_fast_cglm,
         data = data,
         node = node,
         parents = parents,
