@@ -1,7 +1,7 @@
 
 # Grow-Shrink frontend.
 gs = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = FALSE,
     strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
@@ -12,7 +12,7 @@ gs = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
 
 # Incremental Association frontend.
 iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = FALSE,
     strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
@@ -24,7 +24,7 @@ iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
 
 # Fast-IAMB frontend.
 fast.iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = FALSE,
     strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
@@ -36,7 +36,7 @@ fast.iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
 
 # Inter-IAMB frontend.
 inter.iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = FALSE,
     strict = FALSE, undirected = FALSE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
@@ -48,7 +48,7 @@ inter.iamb = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
 
 # MMPC frontend.
 mmpc = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = FALSE,
     strict = FALSE, undirected = TRUE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
@@ -60,7 +60,7 @@ mmpc = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
 
 # Semi-Interleaved HITON-PC.
 si.hiton.pc = function(x, cluster = NULL, whitelist = NULL, blacklist = NULL,
-    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = TRUE,
+    test = NULL, alpha = 0.05, B = NULL, debug = FALSE, optimized = FALSE,
     strict = FALSE, undirected = TRUE) {
 
   bnlearn(x = x, cluster = cluster, whitelist = whitelist,
@@ -95,8 +95,8 @@ hc = function(x, start = NULL, whitelist = NULL, blacklist = NULL,
 
   greedy.search(x = x, start = start, whitelist = whitelist,
     blacklist = blacklist, score = score, heuristic = "hc", debug = debug,
-    expand = c(list(...), restart = restart, perturb = perturb,
-    max.iter = max.iter, maxp = maxp), optimized = optimized)
+    ..., restart = restart, perturb = perturb,
+    max.iter = max.iter, maxp = maxp, optimized = optimized)
 
 }#HC
 
@@ -107,40 +107,29 @@ tabu = function(x, start = NULL, whitelist = NULL, blacklist = NULL,
 
   greedy.search(x = x, start = start, whitelist = whitelist,
     blacklist = blacklist, score = score, heuristic = "tabu", debug = debug,
-    expand = c(list(...), max.iter = max.iter, tabu = tabu, max.tabu = max.tabu,
-    maxp = maxp), optimized = optimized)
+    ..., max.iter = max.iter, tabu = tabu, max.tabu = max.tabu,
+    maxp = maxp, optimized = optimized)
 
 }#TABU
 
 # Generic Restricted Maximization frontend.
 rsmax2 = function(x, whitelist = NULL, blacklist = NULL, restrict = "gs",
-    maximize = "hc", test = NULL, score = NULL, alpha = 0.05, B = NULL,
-    ..., maximize.args = list(), optimized = TRUE, strict = FALSE,
+    maximize = "hc", restrict.args = list(), maximize.args = list(), 
     debug = FALSE) {
 
-  restrict.args = list(test = test, alpha = alpha, B = B, strict = strict)
-  maximize.args = c(list(...), maximize.args)
-
   hybrid.search(x, whitelist = whitelist, blacklist = blacklist,
-    restrict = restrict, maximize = maximize, score = score,
-    restrict.args = restrict.args, maximize.args = maximize.args,
-    optimized = optimized, debug = debug)
+    restrict = restrict, maximize = maximize, restrict.args = restrict.args,
+    maximize.args = maximize.args, debug = debug)
 
 }#RSHC
 
 # MMHC frontend.
-mmhc = function(x, whitelist = NULL, blacklist = NULL, test = NULL,
-    score = NULL, alpha = 0.05, B = NULL, ..., restart = 0, perturb = 1,
-    max.iter = Inf, optimized = TRUE, strict = FALSE, debug = FALSE) {
-
-  restrict.args = list(test = test, alpha = alpha, B = B, strict = strict)
-  maximize.args = c(list(...), restart = restart,
-                   perturb = perturb, max.iter = max.iter)
+mmhc = function(x, whitelist = NULL, blacklist = NULL, 
+    restrict.args = list(), maximize.args = list(), debug = FALSE) {
 
   hybrid.search(x, whitelist = whitelist, blacklist = blacklist,
     restrict = "mmpc", maximize = "hc", restrict.args = restrict.args,
-    maximize.args = maximize.args, score = score, optimized = optimized,
-    debug = debug)
+    maximize.args = maximize.args, debug = debug)
 
 }#MMHC
 
@@ -180,4 +169,4 @@ tree.bayes = function(x, training, explanatory, whitelist = NULL, blacklist = NU
     method = "tree.bayes", whitelist = whitelist, blacklist = blacklist,
     expand = list(estimator = mi, root = root), debug = debug)
 
-}#TAN
+}#TREE.BAYES
